import urllib
import json


class GraphQLClient:
    def __init__(self, endpoint):
        self.endpoint = endpoint
        self.token = None
        self.headername = None

    def execute(self, query, variables=None):
        return self._send(query, variables)

    def inject_token(self, token, headername='Authorization'):
        self.token = token
        self.headername = headername

    def _send(self, query, variables):
        data = {'query': query,
                'variables': variables}
        headers = {'Accept': 'application/json',
                   'Content-Type': 'application/json'}

        if self.token is not None:
            headers[self.headername] = '{}'.format(self.token)

        req = urllib.request.Request(self.endpoint, json.dumps(data).encode('utf-8'), headers)

        try:
            response = urllib.request.urlopen(req)
            return response.read().decode('utf-8')
        except urllib.error.HTTPError as e:
            print((e.read()))
            print('')
            raise e



import json

from monday.resources.base import BaseResource
from monday.query_joins import mutate_item_query, get_item_query, update_item_query, get_item_by_id_query


class ItemResource(BaseResource):
    def __init__(self, token):
        super().__init__(token)

    def create_item(self, board, group, item, column_values=None):
        query = mutate_item_query(board, group, item, column_values)
        return json.loads(self.client.execute(query))

    def fetch_items_by_column_value(self, board, column, value):
        query = get_item_query(board, column, value)
        return json.loads(self.client.execute(query))

    def fetch_items_by_id(self, ids):
        query = get_item_by_id_query(ids)
        return json.loads(self.client.execute(query))

    def change_item_value(self, board, item, column, value):
        query = update_item_query(board, item, column, value)
        return json.loads(self.client.execute(query))

